# SUMAP: Supervised UMAP

A dimensionality-reduction and classification pipeline built on top of UMAP (Uniform Manifold Approximation and Projection) by Leland McInnes and others.

### Links:
* [UMAP on GitHub: ](https://github.com/lmcinnes/umap)